@@ -3,7 +3,7 @@ import os
 import os.path
 import sys
 
-# Ensure we can import "taglist" extension module.
+# Ensure we can import "mongoc" extension module.
 this_path = os.path.dirname(__file__)
 sys.path.append(os.path.normpath(os.path.join(this_path, '../../../build/sphinx')))
 
@@ -11,7 +11,6 @@ from mongoc_common import *
 
 extensions = [
     'mongoc',
-    'taglist',
 ]
 
 # General information about the project.
